import numpy as np
import osmium
from styles import *

class OSM(osmium.SimpleHandler):
    def __init__(self, map):
        osmium.SimpleHandler.__init__(self)

        self.map = map

        landuse = ['forest', 'meadow', 'residential']
        natural = ['bare_rock', 'scree', 'glacier', 'water']
        waterway = ['dam']
        self.areas = {'natural':natural, 'landuse':landuse, 'waterway':waterway}

        highway = ['path', 'track', 'pedestrian', 'residential', 'unclassified', 'tertiary', 'secondary', 'primary', 'motorway', 'motorway_link']
        waterway = ['stream']
        sac_scale = ['mountain_hiking', 'demanding_mountain_hiking', 'alpine_hiking']
        aerialway = ['platter', 't-bar', 'chair_lift', 'mixed_lift', 'gondola', 'cable_car']
        railway = ['rail', 'narrow_gauge', 'light_rail', 'subway', 'tram']
        self.ways = {'waterway':waterway, 'railway':railway, 'highway':highway, 'sac_scale':sac_scale, 'aerialway':aerialway}

        natural_names = ['peak', 'saddle', 'water', 'glacier']
        place = ['hamlet', 'village', 'town', 'city']
        self.names = {'natural':natural_names, 'place':place}

        self.nodes = ['toilets', 'parking', 'atm']

    def area(self, object):
        for K, V in self.areas.items():
            type = object.tags.get(K)
            if type in V:
                for boundary in object.outer_rings():
                    curve = np.array([[p.lat, p.lon] for p in boundary]).T
                    self.map.add_area(curve, area_style[type])
                if 'name' in object.tags and K in self.names.keys() and type in self.names[K]:
                    boundary = np.array([[p.lat, p.lon] for p in next(object.outer_rings())]).T
                    boundary_plus = np.roll(boundary, 1, axis=1)
                    area = np.sum(boundary[0]*boundary_plus[1] - boundary_plus[0]*boundary[1]) / 2
                    if np.abs(area) > 0.25:
                        cx = np.sum((boundary[0] + boundary_plus[0]) * (boundary[0]*boundary_plus[1] - boundary_plus[0]*boundary[1])) / (6*area)
                        cy = np.sum((boundary[1] + boundary_plus[1]) * (boundary[0]*boundary_plus[1] - boundary_plus[0]*boundary[1])) / (6*area)
                        self.map.add_name(object.tags.get('name'), np.array([cx, cy]), name_style[type])

    def way(self, object):
        for K, V in self.ways.items():
            type = object.tags.get(K)
            if type in V:
                curve = np.array([[p.lat, p.lon] for p in object.nodes]).T
                self.map.add_way(curve, way_style[type])

    def node(self, object):
        for k in self.nodes:
            values = [t.v for t in object.tags]
            if k in values:
                self.map.add_node(np.array([object.location.lat, object.location.lon]), node_style[k])

        for K, V in self.names.items():
            type = object.tags.get(K)
            if type in V and 'name' in object.tags:
                try:
                    ele = object.tags.get('ele')
                    if ele is None:
                        name = object.tags.get('name')
                    else:
                        name = object.tags.get('name') + '\n' + str(ele) + 'm'
                except:
                    name = object.tags.get('name')
                self.map.add_name(name, np.array([object.location.lat, object.location.lon]), name_style[type])
