import numpy as np
from cartograph.style import AreaStyle, WayStyle, NameStyle, NodeStyle, ElevationStyle

national_level = 13
regional_level = 14
local_level = 15
hiking_level = 16

elevation_style = ElevationStyle(contour_appears_at=hiking_level, contour_levels=np.linspace(0,5000,250,endpoint=False), contour_color='#55008866', clabel_levelskip=5)

name_style = {}
name_style['peak'] = NameStyle(hiking_level, '#550088', 6, 'normal')
name_style['saddle'] = NameStyle(hiking_level, '#550088', 6, 'normal')
name_style['water'] = NameStyle(local_level, '#4466ff', 7, 'normal')
name_style['glacier'] = NameStyle(hiking_level, '#4466ff', 6, 'normal')

name_style['hamlet'] = NameStyle(hiking_level, '#000000', 6, 'normal')
name_style['village'] = NameStyle(local_level, '#000000', 7, 'normal')
name_style['town'] = NameStyle(regional_level, '#000000', 8, 'normal')
name_style['city'] = NameStyle(national_level, '#000000', 9, 'normal')

node_style = {}
node_style['toilets'] = NodeStyle(hiking_level, '#000000', 'wc', 6, 'normal')
node_style['parking'] = NodeStyle(hiking_level, '#66aaff', 'P', 7, 'bold')
node_style['atm'] = NodeStyle(hiking_level, '#000000', 'atm', 6, 'normal')

way_style = {}
way_style['path'] = WayStyle(hiking_level, '#000000', ':', 1.0, '', 0)
way_style['track'] = WayStyle(hiking_level, '#222222', '--', 1.0, '', 0)
way_style['pedestrian'] = WayStyle(hiking_level, '#cccccc', '-', 1.0, '', 0)
way_style['primary'] = WayStyle(national_level, '#1b69ba', '-', 1.75, '', 0) #'#ff8800'
way_style['secondary'] = WayStyle(regional_level, '#fff080', '-', 1.5, '', 0)
way_style['tertiary'] = WayStyle(local_level, '#ffffff', '-', 1.25, '', 0)
way_style['residential'] = WayStyle(hiking_level, '#ffffff', '-', 1.0, '', 0)
way_style['motorway'] = WayStyle(national_level, '#107f46', '-', 2.0, '', 0) #'#ff4400'
way_style['motorway_link'] = WayStyle(national_level, '#107f46', '-', 2.0, '', 0) #'#ff4400'
way_style['unclassified'] = WayStyle(hiking_level, '#ffffff', '-', 1.0, '', 0)

way_style['stream'] = WayStyle(local_level, '#88aaffff', '-', 1.0, '', 0)

way_style['mountain_hiking'] = WayStyle(hiking_level, '#ffff0066', '-', 1.0, '', 0)
way_style['demanding_mountain_hiking'] = WayStyle(hiking_level, '#ff000066', '-', 1.0, '', 0)
way_style['alpine_hiking'] = WayStyle(hiking_level, '#0000ff66', '-', 1.0, '', 0)

way_style['platter'] = WayStyle(hiking_level, '#444444', '-', 0.5, 'o', 1.0)
way_style['t-bar'] = WayStyle(hiking_level, '#444444', '-', 0.5, 'o', 1.0)
way_style['chair_lift'] = WayStyle(hiking_level, '#444444', '-', 0.5, 'o', 1.0)
way_style['gondola'] = WayStyle(hiking_level, '#444444', '-', 0.75, 's', 1.5)
way_style['cable_car'] = WayStyle(hiking_level, '#444444', '-', 0.75, 's', 1.5)

way_style['rail'] = WayStyle(national_level, '#222222', '-', 0.75, '', 0.2)
way_style['narrow_gauge'] = WayStyle(regional_level, '#222222', '-', 0.5, '', 0.2)
way_style['light_rail'] = WayStyle(regional_level, '#222222', '-', 0.5, '', 0.2)
way_style['subway'] = WayStyle(local_level, '#222222', '-.', 0.5, '', 0.2)
way_style['tram'] = WayStyle(local_level, '#222222', '-', 0.5, '', 0.2)

area_style = {}
area_style['forest'] = AreaStyle(regional_level, '#66aa5566', True, '')
area_style['meadow'] = AreaStyle(regional_level, '#99cc8866', True, '')
area_style['residential'] = AreaStyle(regional_level, '#ffcccc66', True, '')

area_style['water'] = AreaStyle(national_level, '#88aaffff', True, '')
area_style['glacier'] = AreaStyle(local_level, '#ccddff99', True, '')
area_style['bare_rock'] = AreaStyle(regional_level, '#88888866', True, '') #'/|/|/|/|/|'
area_style['scree'] = AreaStyle(hiking_level, '#aaaaaa66', False, '.....')

area_style['dam'] = AreaStyle(hiking_level, '#666666ff', True, '')
# styles['fell'] = apply_style('#666666', '', 0.0, '', 0)
