import numpy as np
import overpass
import osmium
from cartograph import Map
from parse import OSM
from styles import elevation_style

places = {'montreux':(46.431094, 6.912817)}

## Define the map boundaries
zoom_levels = (13, 18)
map = Map()
min_x, max_x, min_y, max_y = map.bound_by_osm_tiles(zoom_levels[0], places['montreux'])

## Fetch the OSM data
print('Downloading OSM data...')
savename = '%d-%d_%d-%d.osm' % (min_x, max_x, min_y, max_y)
api = overpass.API(endpoint='https://overpass-api.de/api/interpreter', timeout=60)
latlon_bounds = map.get_latlon_bounds()
query = overpass.MapQuery(latlon_bounds[0,0]-0.001, latlon_bounds[1,0]-0.001, latlon_bounds[0,1]+0.001, latlon_bounds[1,1]+0.001)
response = api.get(query, responseformat='xml')
with open(savename, 'w') as file:
    file.write(response)

## Process the OSM data
print('Processing OSM data...')
osm = OSM(map)
osm.apply_file(savename, locations=True)

## Elevation data
print('Processing elevation data...')
elevation_data = np.loadtxt('DHM200.txt').T[[1,0,2]]
map.add_elevation(elevation_data, elevation_style)

## Draw map tiles
map.draw_zoom_levels(zoom_levels[0], zoom_levels[1], disp=True)
